"use server";

import { requestGetFetch, requestPostFetch } from "@/utils/fetch";
import { getServerSession, Session } from "next-auth";
import { nextauthOptions } from "../nextauth-options";
import { SearchParams } from "@/types/searchParams";

export async function createDCForm(payload: any) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;

    const path = "v1/dc-forms";

    const cleanedPayload = Object.fromEntries(
      Object.entries(payload).filter(
        ([_, value]) => value !== null || value != ""
      )
    );

    const response = await requestPostFetch({
      path,
      data: { ...cleanedPayload },
      token,
    });

    return response;
  } catch (error: any) {
    throw new Error(error.message);
  }
}

export async function dcFormsRequestList(searchParams?: SearchParams) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;

    const paramsArray = searchParams && Object.entries(searchParams);

    const queryString = paramsArray && paramsArray.map(([key, value]) => `${key}=${value}`).join("&");

    const path = "v1/dc-forms" + `?${queryString ? queryString : ""}`;

    const response = await requestGetFetch({
      path,
      options: {
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: "no-store",
      },
    });
    return response;
  } catch (error) {
    if (error) {
    }
    throw error;
  }
}

export async function getDCFormById(id: number) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user.token;
    const path = `v1/dc-forms/${id}`;
    const response = await requestGetFetch({
      path,
      options: {
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: "no-store",
      },
    });
    return response.data || null;
  } catch (error) {
    throw error;
  }
}

export async function getDcs(searchParams?: SearchParams) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user.token;

    // Dynamically build the query string from searchParams
    const paramsArray = searchParams && Object.entries(searchParams);
    const queryString = paramsArray
      ? paramsArray
          .map(
            ([key, value]) =>
              Array.isArray(value)
                ? `${key}=${value.join(",")}` // Use .join(",") without encoding commas
                : `${key}=${String(value)}` // Encode only non-array values
          )
          .join("&")
      : "";

    const path = "v1/dc-forms" + (queryString ? `?${queryString}` : "");

    const response = await requestGetFetch({
      path,
      options: {
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: "no-store",
      },
    });

    return response;
  } catch (error) {
    throw error;
  }
}
export async function deleteDc(id: number | string) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;
    const path = "v1/dc-forms/" + id;
    const response = await requestGetFetch({
      path,
      options: {
        method: "Delete",
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: "no-store",
      },
    });
    return response;
  } catch (error) {
    if (error) {
    }
    throw error;
  }
}
